# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).
This file follows the formats and conventions from [keepachangelog.com]

Since changes in this pre-1.0.0 stage of the project will be fast,
this changelog won't be properly updated for now.
For progress, keep track of the checklist in the `README.md` file.

## [Unreleased]
### Added
 - Handled those attributes that cannot be plotted and the corresponding legend is not added due to the fact that the associated device is down or the attribute doesn't exist. (!123)

[0.9.2]
 - General bug fixes

[0.9.1]
 - First release with this changelog being updated.
 - Curves names shown at the inspector mode tooltip. (#121, !117)
 - Solve bug with statistics dialog. (#125, !118)
 - Fix f-string new format to .format style. (!119)

[0.9.0]
 - Added range selector for X Axis view on trends. (#108, !112)
 - Added basic "Taurus4 compatible" data file export option. (!113)
 - Added new method to taurus trend to set logarithmic mode programmatically. (!115)
 - Added pyhdbpp as an optional dependency . (!116)



[keepachangelog.com]: http://keepachangelog.com
[TEP17]: https://github.com/taurus-org/taurus/pull/452
[Unreleased]: https://gitlab.com/taurus-org/taurus_pyqtgraph/-/tree/main




